
# Version 1.0.1

+ Update default activation of FLNN-based to None. However, user can still set activation for FLNN-based model for classification problems.
+ Update tests and examples folders.
+ Update required libraries to the newest version (mealpy>=3.0.1, permetrics>=1.5.0)
+ Update docs folder and document page.
+ Update DOI

# Version 1.0.0

+ Add infors (CODE_OF_CONDUCT.md, MANIFEST.in, LICENSE, README.md, requirements.txt, CITATION.cff)
+ Add util modules (data_toolkit, validator, evaluator, expand_util, activation)
+ Add FlnnRegressor and FlnnClassifier classes (Based on Pytorch and Skorch)
+ Add MhaFlnnRegressor and MhaFlnnClassifier classes
+ Add publish workflows
+ Add examples, tests, and documents folders
